@@ -182,6 +182,7 @@ BUILTINS = {
     "all": {
         "round": {"return": "int", "params": {"x": "float"}, "kind": "function"},
         "float": {"return": "float", "params": {"x": "int"}, "kind": "function"},
+        "int": {"return": "int", "params": {"x": "float"}, "kind": "function"},
         "vec2": {
             "return": "vec2",
             "kind": "function",
@@ -240,8 +241,8 @@ BUILTINS = {
             "kind": "function",
             "return": "vec4",
             "overloads": [
-                {"tex": "texture", "sample_position": "vec2"},
-                {"tex": "texture", "index": "int", "sample_position": "vec2"},
+                {"params": {"tex": "texture", "sample_position": "vec2"}},
+                {"params": {"tex": "texture", "index": "int", "sample_position": "vec2"}},
             ],
         },
     },
